@@ -1,5 +1,3 @@
-package test;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -8,9 +6,9 @@ package test;
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,6 +16,7 @@ package test;
  * specific language governing permissions and limitations
  * under the License.
  */
+package test;
 
 /**
  * This is the source class to be scanned for annotations. While scanning, QDox must not try to resolve references to
@@ -27,8 +26,4 @@ package test;
  *
  * @goal test
  */
-public class SomeMojo
-    extends ClassB
-{
-
-}
+public class SomeMojo extends ClassB {}
