@@ -1,5 +1,3 @@
-package org.apache.maven.tools.plugin.extractor;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,31 +16,59 @@ package org.apache.maven.tools.plugin.extractor;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.tools.plugin.extractor;
+
+import java.util.List;
 
 import org.apache.maven.plugin.descriptor.InvalidPluginDescriptorException;
 import org.apache.maven.plugin.descriptor.MojoDescriptor;
 import org.apache.maven.tools.plugin.PluginToolsRequest;
 
-import java.util.List;
-
 /**
  * @author jdcasey
- * @version $Id: MojoDescriptorExtractor.java 1592229 2014-05-03 15:50:05Z hboutemy $
  */
-public interface MojoDescriptorExtractor
-{
-    /** Plexus role for lookup */
-    String ROLE = MojoDescriptorExtractor.class.getName();
+public interface MojoDescriptorExtractor {
+    /**
+     * Returns the "name" (id) of the extractor.
+     *
+     * @since 3.7.0
+     */
+    String getName();
+
+    /**
+     * Returns {@code true} if extractor is deprecated.
+     *
+     * @since 3.7.0
+     */
+    boolean isDeprecated();
+
+    /**
+     * Returns the {@link GroupKey} of extractor, as {@link org.apache.maven.tools.plugin.scanner.MojoScanner} will
+     * execute them grouped, and ordered within groups. Must never return {@code null}.
+     *
+     * @since 3.7.0
+     */
+    GroupKey getGroupKey();
 
     /**
      * Execute the mojo extraction.
      *
      * @param request The {@link PluginToolsRequest} containing information for the extraction process.
-     * @return a list of mojo descriptors.
+     * @return a list of mojo descriptors. These may return HTML values for some fields.
      * @throws ExtractionException if any
      * @throws InvalidPluginDescriptorException if any
      * @since 2.5
      */
-    List<MojoDescriptor> execute( PluginToolsRequest request )
-        throws ExtractionException, InvalidPluginDescriptorException;
-}
\ No newline at end of file
+    List<MojoDescriptor> execute(PluginToolsRequest request)
+            throws ExtractionException, InvalidPluginDescriptorException;
+
+    /**
+     * The default implementation returns {@code null}.
+     * @return the required java version or {@code null} if unknown
+     *
+     * @since 3.8.0
+     */
+    default String getRequiredJavaVersion() {
+        return null;
+    }
+}
